@@ -20,6 +20,13 @@ import os
 from py.path import local
 from .common.workdir import find_basepath
 
+
+def _disallowd_workdirs():
+    return set(
+        local(os.path.expanduser(x))
+        for x in os.environ.get('ANYVC_IGNORED_WORKDIRS',
+                                '/').split(os.pathsep))
+
 def open(path):
     """
     :param path:
@@ -31,8 +38,11 @@ def open(path):
     It uses the backend metadata to find the correct backend and
     won't import unnecessary backends to keep the import time low
     """
-
+    dont_try = _disallowd_workdirs()
     for part in local(path).parts(reverse=True):
+        if part in dont_try:
+            continue
+
         applying = [ backend for backend in get_backends()
                      if backend.is_workdir(part) ]
 
