@@ -1,5 +1,6 @@
 import py
 from tests.helpers import  VcsMan
+import os
 
 from anyvc import metadata
 
@@ -33,9 +34,9 @@ def pytest_configure(config):
     assert test_on,  'you shouldnt disable all test variations'
 
     vcs = config.getvalue('vcs')
-    vcs = vcs.split('-')[0]
     if vcs is None:
         return
+    vcs = vcs.split('-')[0]
     if vcs not in metadata.backends:
         if vcs in metadata.aliases:
             vcs = metadata.aliases[vcs]
@@ -44,6 +45,8 @@ def pytest_configure(config):
             raise KeyError(vcs, '%r not found' % vcs)
 
 
+    os.environ['BZR_EMAIL'] = 'Test <test@example.com>'
+
 funcarg_names = set('mgr repo wd backend'.split())
 
 def pytest_generate_tests(metafunc):
@@ -58,6 +61,10 @@ def pytest_generate_tests(metafunc):
 
 
 def pytest_funcarg__backend(request):
+    """
+    create a cached backend instance that is used the whole session
+    makes instanciating backend cheap
+    """
     vc, spec = request.param
     return request.cached_setup(
             lambda: metadata.get_backend(vc, spec),
@@ -66,6 +73,13 @@ def pytest_funcarg__backend(request):
 
 
 def pytest_funcarg__mgr(request):
+    """
+    create a preconfigured :class:`tests.helplers.VcsMan` instance
+    pass the currently tested backend 
+    and create a tmpdir for the vcs/test combination
+
+    auto-check for the vcs features and skip if necessary
+    """
     vc, spec = request.param
     r = spec or 'local'
     vcdir = request.config.ensuretemp('%s_%s'%(vc, r) )
@@ -73,7 +87,7 @@ def pytest_funcarg__mgr(request):
     backend = request.getfuncargvalue('backend')
 
     required_features = getattr(request.function, 'feature', None)
-    
+
     if required_features:
         required_features = set(required_features.args)
         difference = required_features.difference(backend.features)
@@ -84,9 +98,16 @@ def pytest_funcarg__mgr(request):
     return VcsMan(vc, testdir, spec, backend)
 
 def pytest_funcarg__repo(request):
+    """
+    create a repo below mgf called 'repo'
+    """
     return request.getfuncargvalue('mgr').make_repo('repo')
 
 def pytest_funcarg__wd(request):
+    """
+    create a workdir below mgr called 'wd'
+    if the feature "wd:heavy" is not supported use repo as help
+    """
     mgr = request.getfuncargvalue('mgr')
     if 'wd:heavy' not in mgr.backend.features:
         repo = request.getfuncargvalue('repo')
@@ -94,13 +115,14 @@ def pytest_funcarg__wd(request):
     else:
         wd = mgr.create_wd('wd')
 
-    if hasattr(request.function, 'files'):
-        files = request.function.files.args[0]
+    fp = request.function
+    if hasattr(fp, 'files'):
+        files = fp.files.args[0]
         wd.put_files(files)
         assert wd.has_files(*files)
-        if  hasattr(request.function, 'commit'):
+        if  hasattr(fp, 'commit'):
             wd.add(paths=list(files))
-            wd.commit(message='*')
+            wd.commit(message='initial commit')
     return wd
 
 
